==> substrate-api-sidecar-v0.11.3.tar.gz: substrate-api-sidecar-v0.11.3/src/middleware/error/txErrorMiddleware.spec.ts <==
import { BadRequest, InternalServerError } from 'http-errors';

import {
	callsNextWithErr,
	callsNextWithSentHeaders,
	catchesErrWithResponse,
} from './testUtils';
import { txErrorMiddleware } from './txErrorMiddleware';

const txErrorMiddlewareCallsNextWithErr = callsNextWithErr(txErrorMiddleware);

const txErrorMiddlewareCatchesErrWithResponse = catchesErrWithResponse(
	txErrorMiddleware
);

describe('txErrorMiddleware', () => {
	txErrorMiddlewareCallsNextWithErr('Error', new Error('This is an error'));

	txErrorMiddlewareCallsNextWithErr(
		'BadRequest',
		new BadRequest('bad request')
	);

	txErrorMiddlewareCallsNextWithErr(
		'InternalServerError (http-error which extends Error)',
		new InternalServerError('internal error')
	);

	txErrorMiddlewareCallsNextWithErr('nonsense object', {
		cat: 'in a hat',
	});

	txErrorMiddlewareCallsNextWithErr('ILegacyError', {
		error: 'legacy error',
		statusCode: 500,
	});

	txErrorMiddlewareCallsNextWithErr('IBasicError', {
		error: 'basic error',
	});

	txErrorMiddlewareCatchesErrWithResponse(
		'ITxLegacyError (with data)',
		{
			data: 'some data!',
			cause: 'a cause!',
			error: 'an error!',
		},
		500,
		{
			code: 500,
			data: 'some data!',
			cause: 'a cause!',
			error: 'an error!',
		}
	);

	txErrorMiddlewareCatchesErrWithResponse(
		'ITxLegacyError (without data)',
		{
			cause: 'a cause!',
			error: 'an error!',
		},
		500,
		{
			code: 500,
			cause: 'a cause!',
			error: 'an error!',
		}
	);

	callsNextWithSentHeaders(txErrorMiddleware, {
		data: 'some data!',
		cause: 'a cause!',
		error: 'an error!',
	});
});

==> substrate-api-sidecar-v12.0.1.tar.gz: substrate-api-sidecar-v12.0.1/src/middleware/error/txErrorMiddleware.spec.ts <==
// Copyright 2017-2022 Parity Technologies (UK) Ltd.
// This file is part of Substrate API Sidecar.
//
// Substrate API Sidecar is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program.  If not, see <http://www.gnu.org/licenses/>.

import { BadRequest, InternalServerError } from 'http-errors';

import {
	callsNextWithErr,
	callsNextWithSentHeaders,
	catchesErrWithResponse,
} from './testTools';
import { txErrorMiddleware } from './txErrorMiddleware';

const txErrorMiddlewareCallsNextWithErr = callsNextWithErr(txErrorMiddleware);

const txErrorMiddlewareCatchesErrWithResponse =
	catchesErrWithResponse(txErrorMiddleware);

describe('txErrorMiddleware', () => {
	txErrorMiddlewareCallsNextWithErr('Error', new Error('This is an error'));

	txErrorMiddlewareCallsNextWithErr(
		'BadRequest',
		new BadRequest('bad request')
	);

	txErrorMiddlewareCallsNextWithErr(
		'InternalServerError (http-error which extends Error)',
		new InternalServerError('internal error')
	);

	txErrorMiddlewareCallsNextWithErr('nonsense object', {
		cat: 'in a hat',
	});

	txErrorMiddlewareCallsNextWithErr('ILegacyError', {
		error: 'legacy error',
		statusCode: 500,
	});

	txErrorMiddlewareCallsNextWithErr('IBasicError', {
		error: 'basic error',
	});

	txErrorMiddlewareCatchesErrWithResponse(
		'ITxLegacyError (with data)',
		{
			data: 'some data!',
			cause: 'a cause!',
			error: 'an error!',
		},
		500,
		{
			code: 500,
			data: 'some data!',
			cause: 'a cause!',
			error: 'an error!',
		}
	);

	txErrorMiddlewareCatchesErrWithResponse(
		'ITxLegacyError (without data)',
		{
			cause: 'a cause!',
			error: 'an error!',
		},
		500,
		{
			code: 500,
			cause: 'a cause!',
			error: 'an error!',
		}
	);

	callsNextWithSentHeaders(txErrorMiddleware, {
		data: 'some data!',
		cause: 'a cause!',
		error: 'an error!',
	});
});
